@@ -297,6 +297,8 @@ void			gexiv2_metadata_free				(GExiv2Metadata *self);
  * The file must be an image format supported by Exiv2.
  *
  * Returns: Boolean success indicator
+ *
+ *
  */
 gboolean		gexiv2_metadata_open_path			(GExiv2Metadata *self, const gchar *path, GError **error);
 
@@ -309,7 +311,13 @@ gboolean		gexiv2_metadata_open_path			(GExiv2Metadata *self, const gchar *path,
  *
  * The buffer must be an image format supported by Exiv2.
  *
+ * When called on an already filled meta-data object (i.e. one that has already
+ * been filled by a previous call of [method@GExiv2.Metadata.open_path]) and the
+ * opening of the new path fails, the object will not revert to its previous
+ * state but be in a similar state after calling [method@GExiv2.Metadata.new].
+ *
  * Returns: Boolean success indicator
+ *
  */
 gboolean		gexiv2_metadata_open_buf			(GExiv2Metadata *self, const guint8 *data, glong n_data, GError **error);
 
@@ -322,20 +330,18 @@ gboolean		gexiv2_metadata_open_buf			(GExiv2Metadata *self, const guint8 *data,
  * The stream must be an image format supported by Exiv2.
  *
  * Returns: Boolean success indicator
+ *
  */
+G_DEPRECATED
 gboolean		gexiv2_metadata_open_stream			(GExiv2Metadata *self, ManagedStreamCallbacks* cb, GError **error);
 
-
 /**
  * gexiv2_metadata_from_stream:
- * @self: An instance of #GExiv2Metadata
- * @stream: A #GInputStream to get meta-data from
- * @error: (allow-none): A return location for a #GError or %NULL
  *
- * Read meta-data from a GIO stream
+ * This function does not work and will be removed in a future release.
  *
- * Returns: Boolean success indicator
  */
+G_DEPRECATED
 gboolean		gexiv2_metadata_from_stream			(GExiv2Metadata *self, GInputStream* stream, GError **error);
 
 /**
@@ -348,6 +354,7 @@ gboolean		gexiv2_metadata_from_stream			(GExiv2Metadata *self, GInputStream* str
  * Load only an EXIF buffer, typically stored in a JPEG's APP1 segment.
  *
  * Returns: Boolean success indicator.
+ *
  */
 gboolean		gexiv2_metadata_from_app1_segment	(GExiv2Metadata *self, const guint8 *data, glong n_data, GError **error);
 
@@ -362,10 +369,10 @@ gboolean		gexiv2_metadata_from_app1_segment	(GExiv2Metadata *self, const guint8
  * Returns: Boolean success indicator.
  *
  * Since: 0.10.6
+ *
  */
 gboolean		gexiv2_metadata_save_external			(GExiv2Metadata *self, const gchar *path, GError **error);
 
-
 /**
  * gexiv2_metadata_save_file:
  * @self: An instance of #GExiv2Metadata
@@ -376,6 +383,7 @@ gboolean		gexiv2_metadata_save_external			(GExiv2Metadata *self, const gchar *pa
  * metadata into the image, then writing the image back out.
  *
  * Returns: Boolean success indicator.
+ *
  */
 gboolean		gexiv2_metadata_save_file			(GExiv2Metadata *self, const gchar *path, GError **error);
 
@@ -389,7 +397,9 @@ gboolean		gexiv2_metadata_save_file			(GExiv2Metadata *self, const gchar *path,
  * metadata into the image, then writing the image as a stream back out.
  *
  * Returns: Boolean success indicator.
+ *
  */
+G_DEPRECATED
 gboolean		gexiv2_metadata_save_stream			(GExiv2Metadata *self, ManagedStreamCallbacks* cb, GError **error);
 
 /**
@@ -400,9 +410,26 @@ gboolean		gexiv2_metadata_save_stream			(GExiv2Metadata *self, ManagedStreamCall
  * The Exiv2 Tag Reference can be found at <ulink url="http://exiv2.org/metadata.html"></ulink>
  *
  * Returns: TRUE if the tag is present.
+ *
+ * Deprecated: 0.14.0: Use gexiv2_metadata_try_has_tag() instead.
  */
+G_DEPRECATED_FOR(gexiv2_metadata_try_has_tag)
 gboolean		gexiv2_metadata_has_tag				(GExiv2Metadata *self, const gchar* tag);
 
+/**
+ * gexiv2_metadata_try_has_tag:
+ * @self: An instance of #GExiv2Metadata
+ * @tag: Exiv2 tag
+ * @error: (allow-none): A return location for a #GError or %NULL
+ *
+ * The Exiv2 Tag Reference can be found at <ulink url="http://exiv2.org/metadata.html"></ulink>
+ *
+ * Returns: TRUE if the tag is present.
+ *
+ * Since: 0.14.0
+ */
+gboolean gexiv2_metadata_try_has_tag(GExiv2Metadata* self, const gchar* tag, GError** error);
+
 /**
  * gexiv2_metadata_clear_tag:
  * @self: An instance of #GExiv2Metadata
@@ -413,9 +440,28 @@ gboolean		gexiv2_metadata_has_tag				(GExiv2Metadata *self, const gchar* tag);
  * The Exiv2 Tag Reference can be found at <ulink url="http://exiv2.org/metadata.html"></ulink>
  *
  * Returns: TRUE if the tag was present.
+ *
+ * Deprecated: 0.14.0: Use gexiv2_metadata_try_clear_tag() instead.
  */
+G_DEPRECATED_FOR(gexiv2_metadata_try_clear_tag)
 gboolean		gexiv2_metadata_clear_tag			(GExiv2Metadata *self, const gchar* tag);
 
+/**
+ * gexiv2_metadata_try_clear_tag:
+ * @self: An instance of #GExiv2Metadata
+ * @tag: Exiv2 tag
+ * @error: (allow-none): A return location for a #GError or %NULL
+ *
+ * Removes the Exiv2 tag from the metadata object.
+ *
+ * The Exiv2 Tag Reference can be found at <ulink url="http://exiv2.org/metadata.html"></ulink>
+ *
+ * Returns: TRUE if the tag was present.
+ *
+ * Since: 0.14.0
+ */
+gboolean gexiv2_metadata_try_clear_tag(GExiv2Metadata* self, const gchar* tag, GError** error);
+
 /**
  * gexiv2_metadata_clear:
  * @self: An instance of #GExiv2Metadata
@@ -512,7 +558,7 @@ const gchar*	gexiv2_metadata_get_tag_description	(const gchar *tag);
  * @error: (allow-none): A return location for a #GError or %NULL
  *
  * The names of the various Exiv2 tag types can be found at Exiv2::TypeId,
- * <ulink url="http://exiv2.org/doc/namespaceExiv2.html#5153319711f35fe81cbc13f4b852450c"></ulink>
+ * <ulink url="http://exiv2.org/doc/namespaceExiv2.html#a5153319711f35fe81cbc13f4b852450c"></ulink>
  *
  * The Exiv2 Tag Reference can be found at <ulink url="http://exiv2.org/metadata.html"></ulink>
  *
@@ -527,7 +573,7 @@ const gchar*	gexiv2_metadata_try_get_tag_type	(const gchar *tag, GError **error)
  * @tag: An Exiv2 tag
  *
  * The names of the various Exiv2 tag types can be found at Exiv2::TypeId,
- * <ulink url="http://exiv2.org/doc/namespaceExiv2.html#5153319711f35fe81cbc13f4b852450c"></ulink>
+ * <ulink url="http://exiv2.org/doc/namespaceExiv2.html#a5153319711f35fe81cbc13f4b852450c"></ulink>
  *
  * The Exiv2 Tag Reference can be found at <ulink url="http://exiv2.org/metadata.html"></ulink>
  *
@@ -538,6 +584,25 @@ const gchar*	gexiv2_metadata_try_get_tag_type	(const gchar *tag, GError **error)
 G_DEPRECATED_FOR(gexiv2_metadata_try_get_tag_type)
 const gchar*	gexiv2_metadata_get_tag_type	(const gchar *tag);
 
+/**
+ * gexiv2_metadata_try_tag_supports_multiple_values:
+ * @self: An instance of #GExiv2Metadata
+ * @tag: An Exiv2 tag
+ * @error: (allow-none): A return location for a #GError or %NULL
+ *
+ * The Exiv2 Tag Reference can be found at <ulink url="https://www.exiv2.org/metadata.html"></ulink>
+ *
+ * Multiple value tags are Xmp tags of type "XmpAlt", "XmpBag", "XmpSeq" or "LangAlt", or Iptc
+ * tags marked as Repeatable (which can be of any Iptc type). There are no multiple value Exif
+ * tags.
+ *
+ * Returns: Whether @tag is capable of storing multiple values or not. If @tag is undefined
+ * (i.e. not built-in and not added to @self), then @error is set and %FALSE is returned.
+ *
+ * Since: 0.14.0
+ */
+gboolean gexiv2_metadata_try_tag_supports_multiple_values(GExiv2Metadata* self, const gchar* tag, GError** error);
+
 /**
  * gexiv2_metadata_get_supports_exif:
  * @self: An instance of #GExiv2Metadata
@@ -609,6 +674,8 @@ gint			gexiv2_metadata_get_pixel_height	(GExiv2Metadata *self);
  *
  * The Exiv2 Tag Reference can be found at <ulink url="http://exiv2.org/metadata.html"></ulink>
  *
+ * Tags that support multiple values are returned as a single string, with elements separated by ", ".
+ *
  * Returns: (transfer full) (allow-none): The tag's value as a string
  *
  * Since: 0.12.2
@@ -622,6 +689,9 @@ gchar*			gexiv2_metadata_try_get_tag_string	(GExiv2Metadata *self, const gchar*
  * @value: The value to set or replace the existing value
  * @error: (allow-none): A return location for a #GError or %NULL
  *
+ * If a tag supports multiple values, then @value is added to any existing values. For single
+ * tags, @value replaces the value.
+ *
  * The Exiv2 Tag Reference can be found at <ulink url="http://exiv2.org/metadata.html"></ulink>
  *
  * Returns: TRUE on success
@@ -637,6 +707,8 @@ gboolean		gexiv2_metadata_try_set_tag_string	(GExiv2Metadata *self, const gchar*
  *
  * The Exiv2 Tag Reference can be found at <ulink url="http://exiv2.org/metadata.html"></ulink>
  *
+ * Tags that support multiple values are returned as a single string, with elements separated by ", ".
+ *
  * In case of error, a GLib warning will be logged. Use instead
  * gexiv2_metadata_try_get_tag_string() if you want to avoid this and
  * control if and how the error is outputted.
@@ -656,6 +728,9 @@ gchar*			gexiv2_metadata_get_tag_string		(GExiv2Metadata *self, const gchar* tag
  *
  * The Exiv2 Tag Reference can be found at <ulink url="http://exiv2.org/metadata.html"></ulink>
  *
+ * If a tag supports multiple values, then @value is added to any existing values. For single
+ * value tags, @value replaces the value.
+ *
  * In case of error, a GLib warning will be logged. Use instead
  * gexiv2_metadata_try_set_tag_string() if you want to avoid this and
  * control if and how the error is outputted.
@@ -672,7 +747,7 @@ gboolean		gexiv2_metadata_set_tag_string		(GExiv2Metadata *self, const gchar* ta
  * @self: An instance of #GExiv2Metadata
  * @tag: Exiv2 tag name
  * @type: The GExiv2StructureType specifying the type of structure
- * @error: (allow-none): A return location for a #GError or %nullptr
+ * @error: (allow-none): A return location for a #GError or %NULL
  *
  * The Exiv2 Tag Reference can be found at <ulink url="http://exiv2.org/metadata.html"></ulink>
  *
@@ -701,11 +776,13 @@ gboolean gexiv2_metadata_set_xmp_tag_struct (GExiv2Metadata *self, const gchar*
  * gexiv2_metadata_try_get_tag_interpreted_string:
  * @self: An instance of #GExiv2Metadata
  * @tag: Exiv2 tag name
- * @error: (allow-none): A return location for a #GError or %nullptr
+ * @error: (allow-none): A return location for a #GError or %NULL
  *
  * An interpreted string is one fit for user display.  It may display units or use formatting
  * appropriate to the type of data the tag holds.
  *
+ * Tags that support multiple values are returned as a single string, with elements separated by ", ".
+ *
  * The Exiv2 Tag Reference can be found at <ulink url="http://exiv2.org/metadata.html"></ulink>
  *
  * Returns: (transfer full) (allow-none): The tag's interpreted value as a string
@@ -722,6 +799,8 @@ gchar*			gexiv2_metadata_try_get_tag_interpreted_string (GExiv2Metadata *self, c
  * An interpreted string is one fit for user display.  It may display units or use formatting
  * appropriate to the type of data the tag holds.
  *
+ * Tags that support multiple values are returned as a single string, with elements separated by ", ".
+ *
  * The Exiv2 Tag Reference can be found at <ulink url="http://exiv2.org/metadata.html"></ulink>
  *
  * Returns: (transfer full) (allow-none): The tag's interpreted value as a string
@@ -735,7 +814,7 @@ gchar*			gexiv2_metadata_get_tag_interpreted_string (GExiv2Metadata *self, const
  * gexiv2_metadata_try_get_tag_long:
  * @self: An instance of #GExiv2Metadata
  * @tag: Exiv2 tag name
- * @error: (allow-none): A return location for a #GError or %nullptr
+ * @error: (allow-none): A return location for a #GError or %NULL
  *
  * The Exiv2 Tag Reference can be found at <ulink url="http://exiv2.org/metadata.html"></ulink>
  *
@@ -764,7 +843,7 @@ glong			gexiv2_metadata_get_tag_long		(GExiv2Metadata *self, const gchar* tag);
  * @self: An instance of #GExiv2Metadata
  * @tag: Exiv2 tag name
  * @value: The value to set or replace the existing value
- * @error: (allow-none): A return location for a #GError or %nullptr
+ * @error: (allow-none): A return location for a #GError or %NULL
  *
  * The Exiv2 Tag Reference can be found at <ulink url="http://exiv2.org/metadata.html"></ulink>
  *
@@ -798,8 +877,8 @@ gboolean		gexiv2_metadata_set_tag_long		(GExiv2Metadata *self, const gchar* tag,
  * The Exiv2 Tag Reference can be found at <ulink url="http://exiv2.org/metadata.html"></ulink>
  *
  * Returns: (transfer full) (allow-none) (array zero-terminated=1): The multiple string values of
- * the tag.  Returns NULL if parameters are NULL or @tag does not begin with recognised type of
- * metadata ("Exif.", "Xmp." or "Iptc.").  For a well formed @tag, returns array[0] = NULL if @tag
+ * @tag.  Returns %NULL if parameters are %NULL or @tag does not begin with recognised type of
+ * metadata ("Exif.", "Xmp." or "Iptc.").  For a well formed @tag, returns array[0] = %NULL if @tag
  * is undefined or is not set in the current metadata.
  *
  * Since: 0.12.2
@@ -815,6 +894,10 @@ gchar**			gexiv2_metadata_try_get_tag_multiple	(GExiv2Metadata *self, const gcha
  *
  * The Exiv2 Tag Reference can be found at <ulink url="http://exiv2.org/metadata.html"></ulink>
  *
+ * All previous @tag values are erased. For multiple value tags, each of the non %NULL
+ * entries in @values is stored. For single value tags, only the last non %NULL value
+ * is assigned.
+ *
  * Returns: Boolean success value
  *
  * Since: 0.12.2
@@ -833,8 +916,8 @@ gboolean		gexiv2_metadata_try_set_tag_multiple	(GExiv2Metadata *self, const gcha
  * control if and how the error is outputted.
  *
  * Returns: (transfer full) (allow-none) (array zero-terminated=1): The multiple string values of
- * the tag.  Returns NULL if parameters are NULL or @tag does not begin with recognised type of
- * metadata ("Exif.", "Xmp." or "Iptc.").  For a well formed @tag, returns array[0] = NULL if @tag
+ * the tag.  Returns %NULL if parameters are %NULL or @tag does not begin with recognised type of
+ * metadata ("Exif.", "Xmp." or "Iptc.").  For a well formed @tag, returns array[0] = %NULL if @tag
  * is undefined or is not set in the current metadata.
  * (Note: <ulink url="https://gitlab.gnome.org/GNOME/gexiv2/-/issues/61">xmpText/langAlt bug</ulink>
  *  is fixed in gexiv2_metadata_try_get_tag_multiple())
@@ -852,6 +935,10 @@ gchar**			gexiv2_metadata_get_tag_multiple	(GExiv2Metadata *self, const gchar* t
  *
  * The Exiv2 Tag Reference can be found at <ulink url="http://exiv2.org/metadata.html"></ulink>
  *
+ * All previous @tag values are erased. For multiple value tags, each of the non %NULL
+ * entries in @values is stored. For single value tags, only the last non %NULL value
+ * is assigned.
+ *
  * In case of error, a GLib warning will be logged. Use instead
  * gexiv2_metadata_try_set_tag_multiple() if you want to avoid this and
  * control if and how the error is outputted.
@@ -871,6 +958,9 @@ gboolean		gexiv2_metadata_set_tag_multiple	(GExiv2Metadata *self, const gchar* t
  *
  * The Exiv2 Tag Reference can be found at <ulink url="http://exiv2.org/metadata.html"></ulink>
  *
+ * Tags that support multiple values may be returned as a single byte array, with records separated
+ * by 4x INFORMATION SEPARATOR FOUR (ASCII 0x1c)
+ *
  * Returns: (transfer full) (allow-none): The tag's raw value as a byte array
  *
  * Since: 0.12.2
@@ -884,6 +974,9 @@ GBytes*			gexiv2_metadata_try_get_tag_raw		(GExiv2Metadata *self, const gchar* t
  *
  * The Exiv2 Tag Reference can be found at <ulink url="http://exiv2.org/metadata.html"></ulink>
  *
+ * Tags that support multiple values may bereturned as a single byte array, with records separated
+ * by 4x INFORMATION SEPARATOR FOUR (ASCII 0x1c)
+ *
  * Returns: (transfer full) (allow-none): The tag's raw value as a byte array
  *
  * Deprecated: 0.12.2: Use gexiv2_metadata_try_get_tag_raw() instead.
@@ -1011,6 +1104,7 @@ gboolean		gexiv2_metadata_get_exif_thumbnail (GExiv2Metadata *self, guint8** buf
  * Sets or replaces the EXIF thumbnail with the image in the file
  *
  * Returns: Boolean success value
+ *
  */
 gboolean		gexiv2_metadata_set_exif_thumbnail_from_file (GExiv2Metadata *self, const gchar *path, GError **error);
 
@@ -1019,17 +1113,48 @@ gboolean		gexiv2_metadata_set_exif_thumbnail_from_file (GExiv2Metadata *self, co
  * @self: An instance of #GExiv2Metadata
  * @buffer: (array length=size): A buffer containing thumbnail data
  * @size: (skip): Size of the thumbnail's buffer
+ *
+ * Deprecated: 0.14.0: Use gexiv2_metadata_try_set_exif_thumbnail_from_buffer() instead.
  */
+G_DEPRECATED_FOR(gexiv2_metadata_try_set_exif_thumbnail_from_buffer)
 void			gexiv2_metadata_set_exif_thumbnail_from_buffer (GExiv2Metadata *self, const guint8 *buffer, gint size);
 
+/**
+ * gexiv2_metadata_try_set_exif_thumbnail_from_buffer:
+ * @self: An instance of #GExiv2Metadata
+ * @buffer: (array length=size): A buffer containing thumbnail data
+ * @size: (skip): Size of the thumbnail's buffer
+ * @error: (allow-none): A return location for a #GError or %NULL
+ *
+ * Since: 0.14.0
+ */
+void gexiv2_metadata_try_set_exif_thumbnail_from_buffer(GExiv2Metadata* self,
+                                                        const guint8* buffer,
+                                                        gint size,
+                                                        GError** error);
+
 /**
  * gexiv2_metadata_erase_exif_thumbnail:
  * @self: An instance of #GExiv2Metadata
  *
  * Removes the EXIF thumbnail from the loaded image.
+ *
+ * Deprecated: 0.14.0: Use gexiv2_metadata_try_erase_exif_thumbnail() instead.
  */
+G_DEPRECATED_FOR(gexiv2_metadata_try_erase_exif_thumbnail)
 void			gexiv2_metadata_erase_exif_thumbnail (GExiv2Metadata *self);
 
+/**
+ * gexiv2_metadata_try_erase_exif_thumbnail:
+ * @self: An instance of #GExiv2Metadata
+ * @error: (allow-none): A return location for a #GError or %NULL
+ *
+ * Removes the EXIF thumbnail from the loaded image.
+ *
+ * Since: 0.14.0
+ */
+void gexiv2_metadata_try_erase_exif_thumbnail(GExiv2Metadata* self, GError** error);
+
 /**
  * gexiv2_metadata_get_exif_data:
  * @self: An instance of #GExiv2Metadata
@@ -1039,6 +1164,7 @@ void			gexiv2_metadata_erase_exif_thumbnail (GExiv2Metadata *self);
  * Returns: (transfer full) (allow-none): The content of the EXIF data or %NULL on error
  *
  * Since: 0.12.2
+ *
  */
 GBytes *        gexiv2_metadata_get_exif_data (GExiv2Metadata *self, GExiv2ByteOrder byte_order, GError **error);
 
@@ -1128,31 +1254,86 @@ gchar**			gexiv2_metadata_get_xmp_tags		(GExiv2Metadata *self);
  * @prefix: (in): XMP namespace prefix
  *
  * Returns: (skip): Boolean success value
+ *
+ * Deprecated: 0.14.0: Use gexiv2_metadata_try_register_xmp_namespace() instead.
  */
+G_DEPRECATED_FOR(gexiv2_metadata_try_register_xmp_namespace)
 gboolean        gexiv2_metadata_register_xmp_namespace (const gchar* name, const gchar *prefix);
 
+/**
+ * gexiv2_metadata_try_register_xmp_namespace:
+ * @name: (in): XMP URI name (should end in /)
+ * @prefix: (in): XMP namespace prefix
+ * @error: (allow-none): A return location for a #GError or %NULL
+ *
+ * Returns: (skip): Boolean success value
+ *
+ * Since: 0.14.0
+ */
+gboolean gexiv2_metadata_try_register_xmp_namespace(const gchar* name, const gchar* prefix, GError** error);
+
 /**
  * gexiv2_metadata_unregister_xmp_namespace:
  * @name: (in): XMP URI name (should end in /)
  *
  * Returns: (skip): Boolean success value
+ *
+ * Deprecated: 0.14.0: Use gexiv2_metadata_try_unregister_xmp_namespace() instead.
  */
+G_DEPRECATED_FOR(gexiv2_metadata_try_unregister_xmp_namespace)
 gboolean        gexiv2_metadata_unregister_xmp_namespace (const gchar* name);
 
 /**
- * gexiv2_metadata_unregister_all_xmp_namespaces:
+ * gexiv2_metadata_try_unregister_xmp_namespace:
+ * @name: (in): XMP URI name (should end in /)
+ * @error: (allow-none): A return location for a #GError or %NULL
+ *
+ * Returns: (skip): Boolean success value
+ *
+ * Since: 0.14.0
  */
+gboolean gexiv2_metadata_try_unregister_xmp_namespace(const gchar* name, GError** error);
+
+/**
+ * gexiv2_metadata_unregister_all_xmp_namespaces:
+ *
+ * Deprecated: 0.14.0: Use gexiv2_metadata_try_unregister_all_xmp_namespaces() instead.
+ */
+G_DEPRECATED_FOR(gexiv2_metadata_try_unregister_all_xmp_namespaces)
 void            gexiv2_metadata_unregister_all_xmp_namespaces (void);
 
+/**
+ * gexiv2_metadata_try_unregister_all_xmp_namespaces:
+ * @error: (allow-none): A return location for a #GError or %NULL
+ *
+ * Since: 0.14.0
+ */
+void gexiv2_metadata_try_unregister_all_xmp_namespaces(GError** error);
+
 /**
  * gexiv2_metadata_get_xmp_namespace_for_tag:
- * @tag: (in): Full tag name or XMP namespace identifier
+ * @tag: (in): Full tag name (e.g. "Xmp.dc.subject") or XMP namespace identifier (e.g. "dc")
+ *
  * Returns: (transfer full): %NULL if there was no namespace registered for the tag, the URI of the namespace otherwise.
  *
  * Since: 0.12.2
+ *
+ * Deprecated: 0.14.0: Use gexiv2_metadata_try_get_xmp_namespace_for_tag() instead.
  */
+G_DEPRECATED_FOR(gexiv2_metadata_try_get_xmp_namespace_for_tag)
 char* gexiv2_metadata_get_xmp_namespace_for_tag(const char* tag);
 
+/**
+ * gexiv2_metadata_try_get_xmp_namespace_for_tag:
+ * @tag: (in): Full tag name (e.g. "Xmp.dc.subject") or XMP namespace identifier (e.g. "dc")
+ * @error: (allow-none): A return location for a #GError or %NULL
+ *
+ * Returns: (transfer full): %NULL if there was no namespace registered for the tag, the URI of the namespace otherwise.
+ *
+ * Since: 0.14.0
+ */
+char* gexiv2_metadata_try_get_xmp_namespace_for_tag(const char* tag, GError** error);
+
 /* IPTC functions */
 
 /**
@@ -1193,18 +1374,50 @@ gchar**			gexiv2_metadata_get_iptc_tags		(GExiv2Metadata *self);
  *
  * Returns: A #GExiv2Orientation value representing the EXIF orientation
  * value.
+ *
+ * Deprecated: 0.14.0: Use gexiv2_metadata_try_get_orientation() instead.
  */
+G_DEPRECATED_FOR(gexiv2_metadata_try_get_orientation)
 GExiv2Orientation gexiv2_metadata_get_orientation 	(GExiv2Metadata *self);
 
+/**
+ * gexiv2_metadata_try_get_orientation:
+ * @self: An instance of #GExiv2Metadata
+ * @error: (allow-none): A return location for a #GError or %NULL
+ *
+ * The EXIF Orientation field
+ *
+ * Returns: A #GExiv2Orientation value representing the EXIF orientation
+ * value.
+ *
+ * Since: 0.14.0
+ */
+GExiv2Orientation gexiv2_metadata_try_get_orientation(GExiv2Metadata* self, GError** error);
+
 /**
  * gexiv2_metadata_set_orientation:
  * @self: An instance of #GExiv2Metadata
  * @orientation: The new #GExiv2Orientation for the image.
  *
  * The orientation must be valid and cannot be #GEXIV2_ORIENTATION_UNSPECIFIED.
+ *
+ * Deprecated: 0.14.0: Use gexiv2_metadata_try_set_orientation() instead.
  */
+G_DEPRECATED_FOR(gexiv2_metadata_try_set_orientation)
 void			gexiv2_metadata_set_orientation		(GExiv2Metadata *self, GExiv2Orientation orientation);
 
+/**
+ * gexiv2_metadata_try_set_orientation:
+ * @self: An instance of #GExiv2Metadata
+ * @orientation: The new #GExiv2Orientation for the image.
+ * @error: (allow-none): A return location for a #GError or %NULL
+ *
+ * The orientation must be valid and cannot be #GEXIV2_ORIENTATION_UNSPECIFIED.
+ *
+ * Since: 0.14.0
+ */
+void gexiv2_metadata_try_set_orientation(GExiv2Metadata* self, GExiv2Orientation orientation, GError** error);
+
 /**
  * gexiv2_metadata_get_metadata_pixel_width:
  * @self: An instance of #GExiv2Metadata
@@ -1214,9 +1427,27 @@ void			gexiv2_metadata_set_orientation		(GExiv2Metadata *self, GExiv2Orientation
  * gexiv2_metadata_get_pixel_width()
  *
  * Returns: Width of images in pixels as stored in the metadata
+ *
+ * Deprecated: 0.14.0: Use gexiv2_metadata_try_get_metadata_pixel_width() instead.
  */
+G_DEPRECATED_FOR(gexiv2_metadata_try_get_metadata_pixel_width)
 gint gexiv2_metadata_get_metadata_pixel_width (GExiv2Metadata *self);
 
+/**
+ * gexiv2_metadata_try_get_metadata_pixel_width:
+ * @self: An instance of #GExiv2Metadata
+ * @error: (allow-none): A return location for a #GError or %NULL
+ *
+ * Composite accessor to query the pixel with stored in the metadata. This
+ * might differ from the width of image that is available through
+ * gexiv2_metadata_get_pixel_width()
+ *
+ * Returns: Width of images in pixels as stored in the metadata
+ *
+ * Since: 0.14.0
+ */
+gint gexiv2_metadata_try_get_metadata_pixel_width(GExiv2Metadata* self, GError** error);
+
 /**
  * gexiv2_metadata_get_metadata_pixel_height:
  * @self: An instance of #GExiv2Metadata
@@ -1226,36 +1457,84 @@ gint gexiv2_metadata_get_metadata_pixel_width (GExiv2Metadata *self);
  * gexiv2_metadata_get_pixel_height()
  *
  * Returns: Height of images in pixels as stored in the metadata
+ *
+ * Deprecated: 0.14.0: Use gexiv2_metadata_try_get_metadata_pixel_height() instead.
  */
+G_DEPRECATED_FOR(gexiv2_metadata_try_get_metadata_pixel_height)
 gint gexiv2_metadata_get_metadata_pixel_height (GExiv2Metadata *self);
 
+/**
+ * gexiv2_metadata_try_get_metadata_pixel_height:
+ * @self: An instance of #GExiv2Metadata
+ * @error: (allow-none): A return location for a #GError or %NULL
+ *
+ * Composite accessor to query the pixel with stored in the metadata. This
+ * might differ from the height of image that is available through
+ * gexiv2_metadata_get_pixel_height()
+ *
+ * Returns: Height of images in pixels as stored in the metadata
+ *
+ * Since: 0.14.0
+ */
+gint gexiv2_metadata_try_get_metadata_pixel_height(GExiv2Metadata* self, GError** error);
+
 /**
  * gexiv2_metadata_set_metadata_pixel_width:
  * @self: An instance of #GExiv2Metadata
- * @width: The width of the image as it should be put into the metadata.
+ * @width: The width of the image as it should be put into the metadata
  *
  * Composite setter to update the image's metadata with @width
+ *
+ * Deprecated: 0.14.0: Use gexiv2_metadata_try_set_metadata_pixel_width() instead.
  */
+G_DEPRECATED_FOR(gexiv2_metadata_try_set_metadata_pixel_width)
 void gexiv2_metadata_set_metadata_pixel_width (GExiv2Metadata *self, gint width);
 
+/**
+ * gexiv2_metadata_try_set_metadata_pixel_width:
+ * @self: An instance of #GExiv2Metadata
+ * @width: The width of the image as it should be put into the metadata
+ * @error: (allow-none): A return location for a #GError or %NULL
+ *
+ * Composite setter to update the image's metadata with @width
+ *
+ * Since: 0.14.0
+ */
+void gexiv2_metadata_try_set_metadata_pixel_width(GExiv2Metadata* self, gint width, GError** error);
+
 /**
  * gexiv2_metadata_set_metadata_pixel_height:
  * @self: An instance of #GExiv2Metadata
  * @height: The width of the image as it should be put into the metadata.
  *
  * Update the image's metadata with @height
+ *
+ * Deprecated: 0.14.0: Use gexiv2_metadata_try_set_metadata_pixel_height() instead.
  */
+G_DEPRECATED_FOR(gexiv2_metadata_try_set_metadata_pixel_height)
 void gexiv2_metadata_set_metadata_pixel_height (GExiv2Metadata *self, gint height);
 
+/**
+ * gexiv2_metadata_try_set_metadata_pixel_height:
+ * @self: An instance of #GExiv2Metadata
+ * @height: The width of the image as it should be put into the metadata.
+ * @error: (allow-none): A return location for a #GError or %NULL
+ *
+ * Update the image's metadata with @height
+ *
+ * Since: 0.14.0
+ */
+void gexiv2_metadata_try_set_metadata_pixel_height(GExiv2Metadata* self, gint height, GError** error);
+
 /**
  * gexiv2_metadata_get_comment:
  * @self: An instance of #GExiv2Metadata
  *
  * A composite accessor that uses the first available metadata field from a list of well-known
- * locations to find the photo's comment (or description).  
+ * locations to find the photo's comment (or description).
  *
  * MWG guidelines refer to these as <emphasis>Description</emphasis>: a textual description of a resource's content.
- * 
+ *
  * These fields are:
  *
  * - Exif.Image.ImageDescription  (MWG Guidelines)
@@ -1274,9 +1553,45 @@ void gexiv2_metadata_set_metadata_pixel_height (GExiv2Metadata *self, gint heigh
  * which is more useful for quick or casual use.
  *
  * Returns: (transfer full) (allow-none): The photo's comment field.
+ *
+ * Deprecated: 0.14.0: Use gexiv2_metadata_try_get_comment() instead.
  */
+G_DEPRECATED_FOR(gexiv2_metadata_try_get_comment)
 gchar*			gexiv2_metadata_get_comment			(GExiv2Metadata *self);
 
+/**
+ * gexiv2_metadata_try_get_comment:
+ * @self: An instance of #GExiv2Metadata
+ * @error: (allow-none): A return location for a #GError or %NULL
+ *
+ * A composite accessor that uses the first available metadata field from a list of well-known
+ * locations to find the photo's comment (or description).
+ *
+ * MWG guidelines refer to these as <emphasis>Description</emphasis>: a textual description of a resource's content.
+ *
+ * These fields are:
+ *
+ * - Exif.Image.ImageDescription  (MWG Guidelines)
+ * - Exif.Photo.UserComment
+ * - Exif.Image.XPComment
+ * - Iptc.Application2.Caption    (MWG Guidelines)
+ * - Xmp.dc.description           (MWG Guidelines)
+ * - Xmp.acdsee.notes             (Commonly requested, read only)
+ *
+ * <note>Note that in the EXIF specification Exif.Image.ImageDescription is
+ * described  as "the title of the image".  Also, it does not support
+ * two-byte character codes for encoding.  However, it's still used here for legacy reasons.
+ * </note>
+ *
+ * For fine-grained control, it's recommended to use Exiv2 tags directly rather than this method,
+ * which is more useful for quick or casual use.
+ *
+ * Returns: (transfer full) (allow-none): The photo's comment field.
+ *
+ * Since: 0.14.0
+ */
+gchar* gexiv2_metadata_try_get_comment(GExiv2Metadata* self, GError** error);
+
 /**
  * gexiv2_metadata_set_comment:
  * @self: An instance of #GExiv2Metadata
@@ -1284,9 +1599,25 @@ gchar*			gexiv2_metadata_get_comment			(GExiv2Metadata *self);
  *
  * This is a composite setter that will set a number of fields to the supplied value.  See
  * #gexiv2_metadata_get_comment for more information.
+ *
+ * Deprecated: 0.14.0: Use gexiv2_metadata_try_set_comment() instead.
  */
+G_DEPRECATED_FOR(gexiv2_metadata_try_set_comment)
 void			gexiv2_metadata_set_comment			(GExiv2Metadata *self, const gchar* comment);
 
+/**
+ * gexiv2_metadata_try_set_comment:
+ * @self: An instance of #GExiv2Metadata
+ * @comment: Comment string to set. Must not be %NULL
+ * @error: (allow-none): A return location for a #GError or %NULL
+ *
+ * This is a composite setter that will set a number of fields to the supplied value.  See
+ * #gexiv2_metadata_get_comment for more information.
+ *
+ * Since: 0.14.0
+ */
+void gexiv2_metadata_try_set_comment(GExiv2Metadata* self, const gchar* comment, GError** error);
+
 /**
  * gexiv2_metadata_clear_comment:
  * @self: An instance of #GExiv2Metadata
@@ -1306,9 +1637,28 @@ void			gexiv2_metadata_clear_comment		(GExiv2Metadata *self);
  * rational.  See <ulink url="https://en.wikipedia.org/wiki/Shutter_speed"></ulink> for more information.
  *
  * Returns: (skip): Boolean success value
+ *
+ * Deprecated: 0.14.0: Use gexiv2_metadata_try_get_exposure_time() instead.
  */
+G_DEPRECATED_FOR(gexiv2_metadata_try_get_exposure_time)
 gboolean		gexiv2_metadata_get_exposure_time	(GExiv2Metadata *self, gint *nom, gint *den);
 
+/**
+ * gexiv2_metadata_try_get_exposure_time:
+ * @self: An instance of #GExiv2Metadata
+ * @nom: (out): The numerator
+ * @den: (out): The denominator
+ * @error: (allow-none): A return location for a #GError or %NULL
+ *
+ * Returns the exposure time in seconds (shutter speed, <emphasis>not</emphasis> date-time of exposure) as a
+ * rational.  See <ulink url="https://en.wikipedia.org/wiki/Shutter_speed"></ulink> for more information.
+ *
+ * Returns: (skip): Boolean success value
+ *
+ * Since: 0.14.0
+ */
+gboolean gexiv2_metadata_try_get_exposure_time(GExiv2Metadata* self, gint* nom, gint* den, GError** error);
+
 /**
  * gexiv2_metadata_get_fnumber:
  * @self: An instance of #GExiv2Metadata
@@ -1318,9 +1668,27 @@ gboolean		gexiv2_metadata_get_exposure_time	(GExiv2Metadata *self, gint *nom, gi
  * Exif.Photo.ApertureValue (if available);
  *
  * Returns: The exposure Fnumber as a gdouble, or -1.0 if tag is not present or invalid.
+ *
+ * Deprecated: 0.14.0: Use gexiv2_metadata_try_get_fnumber() instead.
  */
+G_DEPRECATED_FOR(gexiv2_metadata_try_get_fnumber)
 gdouble			gexiv2_metadata_get_fnumber			(GExiv2Metadata *self);
 
+/**
+ * gexiv2_metadata_try_get_fnumber:
+ * @self: An instance of #GExiv2Metadata
+ * @error: (allow-none): A return location for a #GError or %NULL
+ *
+ * See <ulink url="https://en.wikipedia.org/wiki/F-number"></ulink> for more information.
+ * If Exif.Photo.FNumber does not exist, it will fall back to calculating the FNumber from
+ * Exif.Photo.ApertureValue (if available);
+ *
+ * Returns: The exposure Fnumber as a gdouble, or -1.0 if tag is not present or invalid.
+ *
+ * Since: 0.14.0
+ */
+gdouble gexiv2_metadata_try_get_fnumber(GExiv2Metadata* self, GError** error);
+
 /**
  * gexiv2_metadata_get_focal_length:
  * @self: An instance of #GExiv2Metadata
@@ -1328,9 +1696,25 @@ gdouble			gexiv2_metadata_get_fnumber			(GExiv2Metadata *self);
  * See <ulink url="https://en.wikipedia.org/wiki/Flange_focal_distance"></ulink> for more information.
  *
  * Returns: The focal length as a gdouble, or -1.0 if tag is not present or invalid.
+ *
+ * Deprecated: 0.14.0: Use gexiv2_metadata_try_get_focal_length() instead.
  */
+G_DEPRECATED_FOR(gexiv2_metadata_try_get_focal_length)
 gdouble			gexiv2_metadata_get_focal_length	(GExiv2Metadata *self);
 
+/**
+ * gexiv2_metadata_try_get_focal_length:
+ * @self: An instance of #GExiv2Metadata
+ * @error: (allow-none): A return location for a #GError or %NULL
+ *
+ * See <ulink url="https://en.wikipedia.org/wiki/Flange_focal_distance"></ulink> for more information.
+ *
+ * Returns: The focal length as a gdouble, or -1.0 if tag is not present or invalid.
+ *
+ * Since: 0.14.0
+ */
+gdouble gexiv2_metadata_try_get_focal_length(GExiv2Metadata* self, GError** error);
+
 /**
  * gexiv2_metadata_get_iso_speed:
  * @self: An instance of #GExiv2Metadata
@@ -1338,9 +1722,25 @@ gdouble			gexiv2_metadata_get_focal_length	(GExiv2Metadata *self);
  * See <ulink url="https://en.wikipedia.org/wiki/Iso_speed"></ulink> for more information.
  *
  * Returns: The ISO speed rating as a gint, or 0 if tag is not present or invalid.
+ *
+ * Deprecated: 0.14.0: Use gexiv2_metadata_try_get_iso_speed() instead.
  */
+G_DEPRECATED_FOR(gexiv2_metadata_try_get_iso_speed)
 gint			gexiv2_metadata_get_iso_speed		(GExiv2Metadata *self);
 
+/**
+ * gexiv2_metadata_try_get_iso_speed:
+ * @self: An instance of #GExiv2Metadata
+ * @error: (allow-none): A return location for a #GError or %NULL
+ *
+ * See <ulink url="https://en.wikipedia.org/wiki/Iso_speed"></ulink> for more information.
+ *
+ * Returns: The ISO speed rating as a gint, or 0 if tag is not present or invalid.
+ *
+ * Since: 0.14.0
+ */
+gint gexiv2_metadata_try_get_iso_speed(GExiv2Metadata* self, GError** error);
+
 /*
  * GPS functions
  */
@@ -1580,9 +1980,27 @@ GExiv2PreviewProperties** gexiv2_metadata_get_preview_properties (GExiv2Metadata
  *
  * Returns: (transfer full): A #GExiv2PreviewImage instance for the particular
  * #GExiv2PreviewProperties.
+ *
+ * Deprecated: 0.14.0: Use gexiv2_metadata_try_get_preview_image() instead.
  */
+G_DEPRECATED_FOR(gexiv2_metadata_try_get_preview_image)
 GExiv2PreviewImage* gexiv2_metadata_get_preview_image		(GExiv2Metadata *self, GExiv2PreviewProperties *props);
 
+/**
+ * gexiv2_metadata_try_get_preview_image:
+ * @self: An instance of #GExiv2Metadata
+ * @props: A #GExiv2PreviewProperties instance
+ * @error: (allow-none): A return location for a #GError or %NULL
+ *
+ * Returns: (transfer full): A #GExiv2PreviewImage instance for the particular
+ * #GExiv2PreviewProperties.
+ *
+ * Since: 0.14.0
+ */
+GExiv2PreviewImage* gexiv2_metadata_try_get_preview_image(GExiv2Metadata* self,
+                                                          GExiv2PreviewProperties* props,
+                                                          GError** error);
+
 G_END_DECLS
 
 #endif /* GEXIV2_METADATA_H */
